@@ -17,11 +17,11 @@
  * 02111-1307, USA.
  */
 
-#include <glade/glade.h>
+#include <gtk/gtk.h>
 
 void set_fingerprint_label (GtkWidget *enable,
 			    GtkWidget *disable);
-void fingerprint_button_clicked (GladeXML *dialog,
+void fingerprint_button_clicked (GtkBuilder *dialog,
 				 GtkWidget *enable,
 				 GtkWidget *disable);
 
